@@ -33,4 +33,9 @@ from .api import duplicates_detection
 from .api import graph_json_values
 from .api import graph_algoritm_selected
 from .api import basic_metadata_tweets_extracted
-from .api import simple_user_timeline_extraction
\ No newline at end of file
+from .api import simple_user_timeline_extraction
+from .api import load_telegram_file
+from .api import messages_connections
+from .api import nodes_participants_dict
+from .api import nodes_participants_df
+from .api import df_graph_telegram_features
