@@ -425,7 +425,7 @@ def graph_json_values(df_graph, df_basic_data, node_list_df, from_verified):
               'iteration': str(df_graph["iteration"].iloc[i])
             })
       
-    return json.dumps(data), node_list_verified_filter_df
+    return data, node_list_verified_filter_df
 
 def simple_user_timeline_extraction(node_list, consumerKey, consumerSecret,accessToken,accessTokenSecret,filepath, filename,n_groups=1,save_by=300):
     # get_user Returns the 20 most recent statuses posted from the authenticating user or the user specified. 
